/**
 * Parse an RDF file and emit it as n-triples.
 *
 * Usage:
 *    ParseSesame foo.{rdf,ttl}
 *
 * We parse the input RDF file into a Sesame Graph, and then spit it out
 * in n-triples format.
 */

import org.openrdf.model.Statement;
import java.io.IOException;


public class ParseSesame {
    public static void main(String[] args) {
        org.openrdf.rio.RDFParser rp;

        if (args.length != 1) {
            System.err.println("Usage: ParseSesame foo.{rdf,ttl}");
            System.exit(1);
        }

        try {
            String rdfFileName = args[0];
            java.io.File rdfFile = new java.io.File(rdfFileName);
            java.io.InputStream is = new java.io.FileInputStream(rdfFile);

            if (rdfFileName.endsWith(".rdf"))
                rp = new org.openrdf.rio.rdfxml.RDFXMLParser();
            else if (rdfFileName.endsWith(".ttl"))
                rp = new org.openrdf.rio.turtle.TurtleParser();
            else {
                throw new IOException("Don't know how to parse file " + rdfFileName);
            }

            // Parse the rdfFile into the RDFHandler implementation
            MyRDFHandler handler = new MyRDFHandler();
            rp.setRDFHandler(handler);
            rp.parse(is, rdfFile.toURI().toString());

            // The graph is now available in handler.getGraph().
            // Work though it and spit it out in n-triples format.
            // If we wanted to retrieve only some Statements, then
            // handler.getGraph().match(subject,predicate,object) would be useful.
            for (Statement s : handler.getGraph()) {
                System.out.print("<" + s.getSubject()
                                 + "> <" + s.getPredicate() + '>');
                org.openrdf.model.Value v = s.getObject();
                if (v instanceof org.openrdf.model.Literal)
                    System.out.println(" \"" + v.stringValue() + "\" .");
                else
                    System.out.println(" <" + v + "> .");
            }
        } catch (org.openrdf.rio.RDFHandlerException e) {
            System.err.println("Error in RDFHandler: " + e);
        } catch (org.openrdf.rio.RDFParseException e) {
            System.err.println("RDF parsing exception: " + e);
        } catch (java.io.FileNotFoundException e) {
            System.err.println("Can't find file to read: " + e);
        } catch (IOException e) {
            System.err.println("IO error: " + e);
        }
    }
}
